pub fn is_cache_valid(
meta: &CacheMetadata,
root: &Path,
config: &CachedScanConfig,
) -> boolExpand description
Check if a cache is still valid for the given configuration
pub fn is_cache_valid(
meta: &CacheMetadata,
root: &Path,
config: &CachedScanConfig,
) -> boolCheck if a cache is still valid for the given configuration