pub struct Scanner { /* private fields */ }Expand description
Filesystem scanner
Implementations
Sourceimpl Scanner
impl Scanner
pub fn new(config: ScanConfig) -> Self
pub fn with_cancellation(self, token: CancellationToken) -> Self
Sourcepub fn scan(
self,
root_path: PathBuf,
) -> (Receiver<ScanMessage>, JoinHandle<DiskTree>)
pub fn scan( self, root_path: PathBuf, ) -> (Receiver<ScanMessage>, JoinHandle<DiskTree>)
Scan a directory and build a tree Returns a receiver for progress updates and spawns scanning in background